==> nvhpc-compilers-25.3-2-x86_64.pkg.tar.zst: opt/nvidia/hpc_sdk/Linux_x86_64/25.3/compilers/src/iso_fortran_env.f90 <==
! 
!     Copyright (c) 2017, NVIDIA CORPORATION.  All rights reserved.
!
! NVIDIA CORPORATION and its licensors retain all intellectual property
! and proprietary rights in and to this software, related documentation
! and any modifications thereto.  Any use, reproduction, disclosure or
! distribution of this software and related documentation without an express
! license agreement from NVIDIA CORPORATION is strictly prohibited.
! 

!          THIS CODE AND INFORMATION ARE PROVIDED "AS IS" WITHOUT
!   WARRANTY OF ANY KIND, EITHER EXPRESSED OR IMPLIED, INCLUDING BUT
!   NOT LIMITED TO THE IMPLIED WARRANTIES OF MERCHANTABILITY AND/OR
!   FITNESS FOR A PARTICULAR PURPOSE.
!


! iso_fortran_env.f90
! 32/64 bit  linux and windows.  Add further targets as required.

        module ISO_FORTRAN_ENV

public

        integer, parameter, private :: selectedASCII = &
     &                                 selected_char_kind('ASCII')

        integer CHARACTER_KINDS(1) 
        parameter (CHARACTER_KINDS = (/ selectedASCII /))

        integer CHARACTER_STORAGE_SIZE
        parameter (CHARACTER_STORAGE_SIZE = 8)
        integer ERROR_UNIT
        parameter (ERROR_UNIT = 0)
        integer FILE_STORAGE_SIZE
        parameter (FILE_STORAGE_SIZE = 8)
        integer INPUT_UNIT
        parameter (INPUT_UNIT = 5)
        integer IOSTAT_END
        parameter (IOSTAT_END = -1)
        integer IOSTAT_EOR
        parameter (IOSTAT_EOR = -2)
        integer NUMERIC_STORAGE_SIZE
        parameter (NUMERIC_STORAGE_SIZE = 32)
        integer OUTPUT_UNIT
        parameter (OUTPUT_UNIT = 6)

        integer IOSTAT_INQUIRE_INTERNAL_UNIT
        parameter (IOSTAT_INQUIRE_INTERNAL_UNIT=99)
    
        integer INT8
        parameter (INT8 = 1)
        integer INT16
        parameter (INT16 = 2)
        integer INT32
        parameter (INT32 = 4)
        integer INT64
        parameter (INT64 = 8)
        integer LOGICAL8
        parameter (LOGICAL8 = 1)
        integer LOGICAL16
        parameter (LOGICAL16 = 2)
        integer LOGICAL32
        parameter (LOGICAL32 = 4)
        integer LOGICAL64
        parameter (LOGICAL64 = 8)
        integer REAL16
        parameter (REAL16 = 2)
        integer REAL32
        parameter (REAL32 = 4)
        integer REAL64
        parameter (REAL64 = 8)
        integer REAL128
        parameter (REAL128 = -1)

        integer INTEGER_KINDS(4)
        parameter (INTEGER_KINDS = (/INT8, INT16, INT32, INT64/))
        integer LOGICAL_KINDS(4)
        parameter (LOGICAL_KINDS = (/LOGICAL8, LOGICAL16, LOGICAL32, &
    &                                LOGICAL64/))
        integer REAL_KINDS(3)
        parameter (REAL_KINDS = (/REAL16, REAL32, REAL64/))

        end module  ISO_FORTRAN_ENV

==> nvhpc-compilers-25.7-1-x86_64.pkg.tar.zst: opt/nvidia/hpc_sdk/Linux_x86_64/25.7/compilers/src/iso_fortran_env.f90 <==
! 
!     Copyright (c) 2017, NVIDIA CORPORATION.  All rights reserved.
!
! NVIDIA CORPORATION and its licensors retain all intellectual property
! and proprietary rights in and to this software, related documentation
! and any modifications thereto.  Any use, reproduction, disclosure or
! distribution of this software and related documentation without an express
! license agreement from NVIDIA CORPORATION is strictly prohibited.
! 

!          THIS CODE AND INFORMATION ARE PROVIDED "AS IS" WITHOUT
!   WARRANTY OF ANY KIND, EITHER EXPRESSED OR IMPLIED, INCLUDING BUT
!   NOT LIMITED TO THE IMPLIED WARRANTIES OF MERCHANTABILITY AND/OR
!   FITNESS FOR A PARTICULAR PURPOSE.
!


! iso_fortran_env.f90
! 32/64 bit  linux and windows.  Add further targets as required.

        module ISO_FORTRAN_ENV

public

        integer, parameter, private :: selectedASCII = &
     &                                 selected_char_kind('ASCII')

        integer CHARACTER_KINDS(1) 
        parameter (CHARACTER_KINDS = (/ selectedASCII /))

        integer CHARACTER_STORAGE_SIZE
        parameter (CHARACTER_STORAGE_SIZE = 8)
        integer ERROR_UNIT
        parameter (ERROR_UNIT = 0)
        integer FILE_STORAGE_SIZE
        parameter (FILE_STORAGE_SIZE = 8)
        integer INPUT_UNIT
        parameter (INPUT_UNIT = 5)
        integer IOSTAT_END
        parameter (IOSTAT_END = -1)
        integer IOSTAT_EOR
        parameter (IOSTAT_EOR = -2)
        integer NUMERIC_STORAGE_SIZE
        parameter (NUMERIC_STORAGE_SIZE = 32)
        integer OUTPUT_UNIT
        parameter (OUTPUT_UNIT = 6)

        integer IOSTAT_INQUIRE_INTERNAL_UNIT
        parameter (IOSTAT_INQUIRE_INTERNAL_UNIT=99)
    
        integer INT8
        parameter (INT8 = 1)
        integer INT16
        parameter (INT16 = 2)
        integer INT32
        parameter (INT32 = 4)
        integer INT64
        parameter (INT64 = 8)
        integer LOGICAL8
        parameter (LOGICAL8 = 1)
        integer LOGICAL16
        parameter (LOGICAL16 = 2)
        integer LOGICAL32
        parameter (LOGICAL32 = 4)
        integer LOGICAL64
        parameter (LOGICAL64 = 8)
        integer REAL32
        parameter (REAL32 = 4)
        integer REAL64
        parameter (REAL64 = 8)
        integer REAL128
        parameter (REAL128 = -1)

        integer INTEGER_KINDS(4)
        parameter (INTEGER_KINDS = (/INT8, INT16, INT32, INT64/))
        integer LOGICAL_KINDS(4)
        parameter (LOGICAL_KINDS = (/LOGICAL8, LOGICAL16, LOGICAL32, &
    &                                LOGICAL64/))
        integer REAL_KINDS(2)
        parameter (REAL_KINDS = (/REAL32, REAL64/))

        end module  ISO_FORTRAN_ENV
